@@ -470,15 +470,13 @@ class system_info(object):
                   ):
         self.__class__.info = {}
         self.local_prefixes = []
-        defaults = {}
-        defaults['library_dirs'] = os.pathsep.join(default_lib_dirs)
-        defaults['include_dirs'] = os.pathsep.join(default_include_dirs)
-        defaults['runtime_library_dirs'] = os.pathsep.join(default_runtime_dirs)
-        defaults['rpath'] = ''
-        defaults['src_dirs'] = os.pathsep.join(default_src_dirs)
-        defaults['search_static_first'] = str(self.search_static_first)
-        defaults['extra_compile_args'] = ''
-        defaults['extra_link_args'] = ''
+        defaults = {'library_dirs': os.pathsep.join(default_lib_dirs),
+                    'include_dirs': os.pathsep.join(default_include_dirs),
+                    'runtime_library_dirs': os.pathsep.join(default_runtime_dirs),
+                    'rpath': '',
+                    'src_dirs': os.pathsep.join(default_src_dirs),
+                    'search_static_first': str(self.search_static_first),
+                    'extra_compile_args': '', 'extra_link_args': ''}
         self.cp = ConfigParser(defaults)
         self.files = []
         self.files.extend(get_standard_file('.numpy-site.cfg'))
@@ -631,7 +629,7 @@ class system_info(object):
         dirs.extend(default_dirs)
         ret = []
         for d in dirs:
-            if not os.path.isdir(d):
+            if len(d) > 0 and not os.path.isdir(d):
                 warnings.warn('Specified path %s is invalid.' % d)
                 continue
 
@@ -665,7 +663,10 @@ class system_info(object):
         return [b for b in [a.strip() for a in libs.split(',')] if b]
 
     def get_libraries(self, key='libraries'):
-        return self.get_libs(key, '')
+        if hasattr(self, '_lib_names'):
+            return self.get_libs(key, default=self._lib_names)
+        else:
+            return self.get_libs(key, '')
 
     def library_extensions(self):
         static_exts = ['.a']
@@ -679,11 +680,6 @@ class system_info(object):
             exts.append('.dll.a')
         if sys.platform == 'darwin':
             exts.append('.dylib')
-        # Debian and Ubuntu added a g3f suffix to shared library to deal with
-        # g77 -> gfortran ABI transition
-        # XXX: disabled, it hides more problem than it solves.
-        #if sys.platform[:5] == 'linux':
-        #    exts.append('.so.3gf')
         return exts
 
     def check_libs(self, lib_dirs, libs, opt_libs=[]):
@@ -997,13 +993,10 @@ class mkl_info(system_info):
             l = 'mkl'  # use shared library
             if cpu.is_Itanium():
                 plt = '64'
-                #l = 'mkl_ipf'
             elif cpu.is_Xeon():
                 plt = 'intel64'
-                #l = 'mkl_intel64'
             else:
                 plt = '32'
-                #l = 'mkl_ia32'
             if l not in self._lib_mkl:
                 self._lib_mkl.insert(0, l)
             system_info.__init__(
@@ -1245,8 +1238,6 @@ class atlas_3_10_blas_info(atlas_3_10_info):
 class atlas_3_10_threads_info(atlas_3_10_info):
     dir_env_var = ['PTATLAS', 'ATLAS']
     _lib_names = ['tatlas']
-    #if sys.platfcorm[:7] == 'freebsd':
-        ## I don't think freebsd supports 3.10 at this time - 2014
     _lib_atlas = _lib_names
     _lib_lapack = _lib_names
 
@@ -1537,7 +1528,6 @@ class lapack_opt_info(system_info):
                                              ('HAVE_CBLAS', None)])
                 return
 
-        #atlas_info = {} ## uncomment for testing
         need_lapack = 0
         need_blas = 0
         info = {}
@@ -1569,7 +1559,6 @@ class lapack_opt_info(system_info):
 
         if need_blas:
             blas_info = get_info('blas')
-            #blas_info = {} ## uncomment for testing
             if blas_info:
                 dict_append(info, **blas_info)
             else:
@@ -1943,13 +1932,6 @@ class _numpy_info(system_info):
                       '"\\"%s\\""' % (vrs)),
                       (self.modulename.upper(), None)]
             break
-##         try:
-##             macros.append(
-##                 (self.modulename.upper()+'_VERSION_HEX',
-##                  hex(vstr2hex(module.__version__))),
-##                 )
-##         except Exception as msg:
-##             print msg
         dict_append(info, define_macros=macros)
         include_dirs = self.get_include_dirs()
         inc_dir = None
@@ -2324,17 +2306,6 @@ class umfpack_info(system_info):
         self.set_info(**info)
         return
 
-## def vstr2hex(version):
-##     bits = []
-##     n = [24,16,8,4,0]
-##     r = 0
-##     for s in version.split('.'):
-##         r |= int(s) << n[0]
-##         del n[0]
-##     return r
-
-#--------------------------------------------------------------------
-
 
 def combine_paths(*args, **kws):
     """ Return a list of existing paths composed by all combinations of
